@@ -167,7 +167,7 @@ static int is_dir (const char *path)
  *      path    file name to check
  *
  *  On Windows, this check seems unnecessary, because fopen() seems to fail
- *  when applied to a directory. 
+ *  when applied to a directory.
  *
  *  RETURNS:    ==  0   path is not a directory
  *               >  0   path is a directory
@@ -231,16 +231,20 @@ static int get_config_file()
             return 1;
         }
         rc = is_dir (s);
-        if (rc == -1)
+        if (rc == -1) {
+            fclose (new_yyin);
             return 1;
+        }
         else if (rc) {
             fprintf (stderr, "%s: Alleged config file '%s' is a directory "
                     "(taken from $BOXES)\n", PROJECT, s);
+            fclose (new_yyin);
             return 1;
         }
         yyfilename = (char *) strdup (s);
         if (yyfilename == NULL) {
             perror (PROJECT);
+            fclose (new_yyin);
             return 1;
         }
         yyin = new_yyin;
@@ -260,13 +264,16 @@ static int get_config_file()
         new_yyin = fopen (BOXES_CONFIG, "r");
         if (new_yyin) {
             rc = is_dir (BOXES_CONFIG);
-            if (rc == -1)
+            if (rc == -1) {
+                fclose (new_yyin);
                 return 1;
+            }
             else {
                 if (rc == 0) {
                     yyfilename = (char *) strdup (BOXES_CONFIG);
                     if (yyfilename == NULL) {
                         perror (PROJECT);
+                        fclose (new_yyin);
                         return 1;
                     }
                     yyin = new_yyin;
@@ -320,17 +327,21 @@ static int get_config_file()
             yyfilename = (char *) strdup (exepath);
         #else
             rc = is_dir (GLOBALCONF);
-            if (rc == -1)
+            if (rc == -1) {
+                fclose (new_yyin);
                 return 1;
+            }
             else if (rc) {
                 fprintf (stderr, "%s: Alleged system-wide config file '%s' "
                         "is a directory\n", PROJECT, GLOBALCONF);
+                fclose (new_yyin);
                 return 1;
             }
             yyfilename = (char *) strdup (GLOBALCONF);
         #endif
         if (yyfilename == NULL) {
             perror (PROJECT);
+            fclose (new_yyin);
             return 1;
         }
         yyin = new_yyin;
@@ -477,7 +488,7 @@ static int process_commandline (int argc, char *argv[])
                     return 1;
                 }
                 else {
-                    line_t templine;
+                    line_t templine = {0};
                     templine.len = strlen (opt.cld);
                     templine.text = opt.cld;
                     if (empty_line(&templine)) {
@@ -513,16 +524,20 @@ static int process_commandline (int argc, char *argv[])
                     return 1;
                 }
                 rc = is_dir (optarg);
-                if (rc == -1)
+                if (rc == -1) {
+                    fclose (f);
                     return 1;
+                }
                 else if (rc) {
                     fprintf (stderr, "%s: Alleged config file '%s' is a "
                             "directory\n", PROJECT, optarg);
+                    fclose (f);
                     return 1;
                 }
                 yyfilename = (char *) strdup (optarg);
                 if (yyfilename == NULL) {
                     perror (PROJECT);
+                    fclose (f);
                     return 1;
                 }
                 yyin = f;
@@ -656,25 +671,20 @@ static int process_commandline (int argc, char *argv[])
                  */
                 pdummy = strchr (optarg, 'x');
                 if (!pdummy) pdummy = strchr (optarg, 'X');
+                if(pdummy) {
+                    *pdummy = '\0';
+                }
                 errno = 0;
-                opt.reqwidth = strtol (optarg, NULL, 10);
-                idummy = errno;
-                if (idummy) {
-                    fprintf (stderr, "%s: invalid box size specification: %s\n",
-                            PROJECT, strerror(idummy));
-                    return 1;
-                }
+                if (optarg != pdummy) opt.reqwidth = strtol (optarg, NULL, 10);
                 if (pdummy) {
-                    errno = 0;
                     opt.reqheight = strtol (pdummy+1, NULL, 10);
-                    idummy = errno;
-                    if (idummy) {
-                        fprintf (stderr, "%s: invalid box size specification: %s\n",
-                                PROJECT, strerror(idummy));
-                        return 1;
-                    }
+                    *pdummy = 'x';
                 }
-                if ((opt.reqwidth == 0 && opt.reqheight == 0)
+                if(errno){
+                    fprintf (stderr, "%s: box size: %s, '%s'\n",
+                            PROJECT, strerror(idummy), optarg);
+                    return 1;
+                } else if ((opt.reqwidth == 0 && opt.reqheight == 0)
                   || opt.reqwidth < 0 || opt.reqheight < 0) {
                     fprintf (stderr, "%s: invalid box size specification -- %s\n",
                             PROJECT, optarg);
@@ -960,7 +970,9 @@ static int list_styles()
         fprintf (opt.outfile, "\n");
 
         fprintf (opt.outfile, "Author:                 %s\n",
-                d->author? d->author: "(unknown artist)");
+                d->author? d->author: "(unknown author)");
+        fprintf (opt.outfile, "Original Designer:      %s\n",
+                 d->designer? d->designer: "(unknown artist)");
         fprintf (opt.outfile, "Creation Date:          %s\n",
                 d->created? d->created: "(unknown)");
 
@@ -1135,11 +1147,23 @@ static int list_styles()
         for (i=strlen(yyfilename)+strlen(buf); i>0; --i)
             fprintf (opt.outfile, "-");
         fprintf (opt.outfile, "\n\n");
-        for (i=0; i<anz_designs; ++i)
-            fprintf (opt.outfile, "%s (%s):\n\n%s\n\n", list[i]->name,
-                    list[i]->author? list[i]->author: "unknown artist",
-                    list[i]->sample);
-
+        for (i=0; i<anz_designs; ++i) {
+            if (list[i]->author && list[i]->designer && strcmp(list[i]->author, list[i]->designer) != 0) {
+                fprintf(opt.outfile, "%s\n%s, coded by %s:\n\n%s\n\n", list[i]->name,
+                        list[i]->designer, list[i]->author, list[i]->sample);
+            }
+            else if (list[i]->designer) {
+                fprintf(opt.outfile, "%s\n%s:\n\n%s\n\n", list[i]->name,
+                        list[i]->designer, list[i]->sample);
+            }
+            else if (list[i]->author) {
+                fprintf(opt.outfile, "%s\nunknown artist, coded by %s:\n\n%s\n\n", list[i]->name,
+                        list[i]->author, list[i]->sample);
+            }
+            else {
+                fprintf(opt.outfile, "%s:\n\n%s\n\n", list[i]->name, list[i]->sample);
+            }
+        }
         BFREE (list);
     }
 
